@@ -1,5 +1,6 @@
 var mem_8c =
 [
+    [ "memblock", "structmemblock.html", "structmemblock" ],
     [ "_GNU_SOURCE", "mem_8c.html#a369266c24eacffb87046522897a570d5", null ],
     [ "F_ADD_SEALS", "mem_8c.html#a3c9cb62957637bb3b3a869cbbe5e4aaa", null ],
     [ "F_GET_SEALS", "mem_8c.html#a0d7e40a9933d11da2fc1b0b1b863eec3", null ],
@@ -10,5 +11,7 @@ var mem_8c =
     [ "F_SEAL_WRITE", "mem_8c.html#a82af8008b212e99dd3a8b8daa2138170", null ],
     [ "MFD_ALLOW_SEALING", "mem_8c.html#a1d9ebf7ab094a827cd93d1e49e81e8a0", null ],
     [ "MFD_CLOEXEC", "mem_8c.html#a3268e6d65db2950f67f6082946d16952", null ],
-    [ "USE_MEMFD", "mem_8c.html#aa3b33676b8bd10a4280ec5f9a4f86831", null ]
+    [ "USE_MEMFD", "mem_8c.html#aa3b33676b8bd10a4280ec5f9a4f86831", null ],
+    [ "pw_memblock_find", "mem_8c.html#a713318b5b2bfd6908f9c1bbf5ae2a714", null ],
+    [ "pw_memblock_import", "mem_8c.html#a0486f0e6831d9ee340acb8288e60dc33", null ]
 ];
\ No newline at end of file
