@@ -80,9 +80,9 @@ var NAVTREEINDEX =
 "annotated.html",
 "data-loop_8h.html#abfa6227e4d5ff8870e856769871ae0f7",
 "introspect_8c.html#a5a689bbb4ce49768274b878c9505b0d4",
-"node_8h.html#af97e4e0860859339a98f01579c7df551",
-"resource_8h.html#a438364782ffd0444d89c747562e204f0",
-"structpw__module__proxy__events.html"
+"page_client.html",
+"resource_8h.html#a7c6de11938397e575506360ba3b8b922",
+"structpw__node__events.html#a262580b630f298b77b491eea272a3a8f"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
