@@ -1,15 +1,11 @@
 var NAVTREEINDEX4 =
 {
-"resource_8h.html#a438364782ffd0444d89c747562e204f0":[9,0,46,3],
-"resource_8h.html#a5991b9355bf5bce75ef0333a28f90513":[9,0,46,13],
-"resource_8h.html#a5d4539677f164ae50e53d8b5b4bcfd79":[9,0,46,5],
 "resource_8h.html#a7c6de11938397e575506360ba3b8b922":[9,0,46,17],
 "resource_8h.html#a91805ad55d5fc0a29b40e9265edf6c09":[9,0,46,8],
 "resource_8h.html#aa3b26c60acd0c1d008d294a5885d416c":[9,0,46,20],
 "resource_8h.html#aa7213c5651700a4bc6bef6df6cc952e9":[9,0,46,11],
 "resource_8h.html#aab37d37e596381fec6da22531f78d7bb":[9,0,46,14],
 "resource_8h.html#aadff480a3e38ec195e07567c1e46ab54":[9,0,46,6],
-"resource_8h.html#aaf0cb7865e43ef0be79db090a18266c5":[9,0,46,1],
 "resource_8h.html#ab9e159d75b7efe39bd53b64055244092":[9,0,46,9],
 "resource_8h.html#ac7d13ba52bc1796d4baca39ddc4a6f0c":[9,0,46,16],
 "resource_8h.html#ade7574d78f4235011d58ed567a64fd55":[9,0,46,4],
@@ -222,9 +218,9 @@ var NAVTREEINDEX4 =
 "structpw__map.html#a6fc621171dbc57de8c44d26f639d2f1b":[8,0,37,8],
 "structpw__map.html#a962f1ba02a79802e16088c4ae8174804":[8,0,37,0],
 "structpw__map.html#a9656703501cdaa5a82adb9db60f76fc6":[8,0,37,5],
-"structpw__map.html#ab8651adcaa6696e6831a2e33ed6b233b":[8,0,37,1],
 "structpw__map.html#acdd13c22e79cecf19a28d30e1154d323":[8,0,37,2],
 "structpw__map.html#acf2ad4417afa20b00e4a1f3837573d87":[8,0,37,7],
+"structpw__map.html#adcd4d2843a41d2f0d70bfd80790a9518":[8,0,37,1],
 "structpw__map.html#ae39fd79002006e438f59e1bb90b334a8":[8,0,37,3],
 "structpw__map__range.html":[8,0,39],
 "structpw__map__range.html#a3b7bd63b490e27ae035b10fa535357a4":[8,0,39,2],
@@ -249,5 +245,9 @@ var NAVTREEINDEX4 =
 "structpw__module__info.html#a8991e7a078e6d92aa05e1922efc5bc53":[8,0,43,0],
 "structpw__module__info.html#a9a30a350e085c46a0be10df7ed9c364d":[8,0,43,5],
 "structpw__module__info.html#aae79b994769838377e2b549736f12de3":[8,0,43,1],
-"structpw__module__info.html#ae2e5f1630b990641c49fdeafb8e496b5":[8,0,43,4]
+"structpw__module__info.html#ae2e5f1630b990641c49fdeafb8e496b5":[8,0,43,4],
+"structpw__module__proxy__events.html":[8,0,44],
+"structpw__module__proxy__events.html#a636f903fb1c285c6df16d25483117213":[8,0,44,0],
+"structpw__module__proxy__events.html#ad8bc3f647fdde20aa4e8b695d3fb5cc9":[8,0,44,1],
+"structpw__node__events.html":[8,0,46]
 };
